/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.nodediscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.AbstractNodeDiscovery;
import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;

import java.io.UnsupportedEncodingException;

import java.net.URLDecoder;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.PageContext;


/**
 * <p>
 * This empty tag will discover the current node from the HttpServletRequest. This implementation will return a valid
 * URL (with query string if specified) in the getCurrentNode() method. This tag does not support additional
 * attributes.
 * </p>
 *
 * <p>
 * <b>Implementation notes:</b> This tag/implementation can be used to discover the node based on an
 * HttpServletRequest. This class can be called directly to discover the current node, or can be used as a tag in the
 * JSP page before the BreadCrumbTrailTag.
 * </p>
 *
 * <p>
 * <b>Thread Safety:</b> This class is thread safe in the context of the JSP rendering process.
 * </p>
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public class HttpServletNodeDiscoveryTag extends AbstractNodeDiscovery {
    /**
     * <p>
     * Constructs the HttpServletNodeDiscoveryTag. Simply calls the superclass constructor.
     * </p>
     */
    public HttpServletNodeDiscoveryTag() {
        super();
    }

    /**
     * <p>
     * Discovers the node url from an HttpServletRequest. If the request is not of HttpServletRequest type, null is
     * returned. Otherwise the current node is constructed with the title attribute and the URL (with query string if
     * any).
     * </p>
     *
     * @param pageContext A non-null page context to use
     *
     * @return A non-null node representing the current url or null if the node couldn't be determined
     *
     * @throws IllegalArgumentException if the pageContext is null
     */
    public BreadCrumbNode getCurrentNode(PageContext pageContext) {
        if (pageContext == null) {
            throw new IllegalArgumentException("pageContext is null");
        }
        if (!(pageContext.getRequest() instanceof HttpServletRequest)) {
            return null;
        }

        // read the url and query string from the http request
        HttpServletRequest request = (HttpServletRequest) pageContext.getRequest();

        StringBuffer sb = new StringBuffer(request.getRequestURI());
        String queryString = request.getQueryString();

        // add the query string to the url if available
        if (queryString != null) {
            sb.append("?");
            sb.append(queryString);
        }

        String url = sb.toString();

        try {
            // decode the url
            url = URLDecoder.decode(url, "utf-8");
        } catch (UnsupportedEncodingException e) {
            // should not happen
        }
        return new BreadCrumbNode(url, getTitle());
    }
}
