/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.cactus.JspTestCase;

import javax.servlet.jsp.PageContext;


/**
 * Unit tests for AbstractNodeDiscovery implementation.
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class AbstractNodeDiscoveryTest extends JspTestCase {
    /**
     * The AbstractNodeDiscovery instance to test against.
     */
    private AbstractNodeDiscovery tag = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(AbstractNodeDiscoveryTest.class);

        return suite;
    }

    /**
     * Prepares an AbstractNodeDiscovery instance for testing.
     */
    protected void setUp() {
        tag = new SimpleAbstractNodeDiscovery();
        tag.setTitle("title");
        tag.setPageContext(pageContext);
    }

    /**
     * Test of doStartTag method. Should return SKIP_BODY. Also verifies if the BREADCRUMB_CURRENT_NODE attribute
     * references a non-null node.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testDoStartTag() throws Exception {
        assertEquals("SKIP_BODY is not returned", tag.SKIP_BODY, tag.doStartTag());
        assertNotNull("Fails to set current node to attribute",
            pageContext.getAttribute(BreadCrumbTrailTag.BREADCRUMB_CURRENT_NODE));
    }

    /**
     * Test of getTitle and setTitle methods. Verifies it by getting the title back after setting it.
     */
    public void testGetSetTitle() {
        String title = "title2";

        tag.setTitle(title);
        assertEquals("Returns an incorrect title", title, tag.getTitle());
    }

    /**
     * Test of release method. Verifies if data members are reset to their initial values.
     */
    public void testRelease() {
        tag.release();
        assertNull("Fails to reset title", tag.getTitle());
    }

    /**
     * A simple implementation of AbstractNodeDiscovery class for testing.
     */
    private class SimpleAbstractNodeDiscovery extends AbstractNodeDiscovery {
        /**
         * Default constructor. Simply calls the super constructor.
         */
        public SimpleAbstractNodeDiscovery() {
            super();
        }

        /**
         * Retrieves the node representation of the current page.
         *
         * @param pageContext A non-null page context to use
         *
         * @return A non-null node representing the current url
         */
        public BreadCrumbNode getCurrentNode(PageContext pageContext) {
            return new BreadCrumbNode("url", "title");
        }
    }
}
