/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;
import com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery.nodematchers.RegexNodeMatcher;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * Unit tests for NodePair implementation.
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class NodePairTest extends TestCase {
    /**
     * The NodePair instance to test against.
     */
    private NodePair nodePair = null;

    /**
     * The node associated with the NodePair.
     */
    private BreadCrumbNode node = null;

    /**
     * The node matcher associated with the NodePair.
     */
    private NodeMatcher nodeMatcher = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(NodePairTest.class);

        return suite;
    }

    /**
     * Prepares a NodePair instance for testing.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    protected void setUp() throws Exception {
        node = new BreadCrumbNode("url", "title");
        nodeMatcher = new RegexNodeMatcher("title", "url", ".*");
        nodePair = new NodePair(node, nodeMatcher);
    }

    /**
     * Test of constructor with null node. Expects IllegalArgumentException.
     */
    public void testConstructor_NullNode() {
        try {
            new NodePair(null, nodeMatcher);
            fail("Creates NodePair with null node");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of getNode method with node having non-null title. Verifies if it returns the node set in constructor.
     */
    public void testGetNode_NonNullTitle() {
        assertEquals("Returns an incorrect node", node, nodePair.getNode());
    }

    /**
     * Test of getNode method with node having null title. Verifies if it does not return the node set in constructor.
     * Also verifies if the returned node has the title from the node matcher.
     */
    public void testGetNode_NullTitle() {
        node = new BreadCrumbNode("url", null);
        nodePair = new NodePair(node, nodeMatcher);

        assertFalse("Returns an incorrect node", node.equals(nodePair.getNode()));
        assertEquals("Fails to set the title", "title", nodePair.getNode().getTitle());
    }

    /**
     * Test of getNodeMatcher method. Verifies if it returns the node matcher set in constructor.
     */
    public void testGetNodeMatcher() {
        assertEquals("Returns an incorrect node matcher", nodeMatcher, nodePair.getNodeMatcher());
    }
}
